#!/usr/bin/env python3
#--------------------------------------------------------------#
# Script to extract water depths at observation points
#--------------------------------------------------------------#
import sys
import os
import xarray as xr
import numpy as np
import scipy.interpolate
from scipy import integrate
import matplotlib.pyplot as plt
xr.set_options(display_max_rows=1000)
#--------------------------------------------------------------#
## Preset turbine locations
turbLocs = np.array([1972927.5424031, 638179.130403393,
	1972845.63513105, 638138.344535915,
	1972773.93519024, 638101.705864012,
	1973000.50316424, 638167.106922289])

turbLocs = turbLocs.reshape((-1,2))
turbLocsUpstream = np.zeros_like(turbLocs)
turbOrientations = [25.85, 25.85, 25.85, -22.0424]
turbAxisHeights = [68.257, 67.986, 67.747, 67.986]
nDia = 3.3
turbHeight = 1

numTurbs = len(turbLocs)

# Find reference distances upstream of turbines
dx = nDia*turbHeight*np.cos(np.deg2rad(turbOrientations))
dy = nDia*turbHeight*np.sin(np.deg2rad(turbOrientations))

for i in range(numTurbs):
  turbLocsUpstream[i][0] = turbLocs[i][0] + dx[i]     
  turbLocsUpstream[i][1] = turbLocs[i][1] + dy[i]

#--------------------------------------------------------------#
## Read from command line
nArgv = len(sys.argv)
if nArgv <= 1:
    print('Missing folder(s) argument. Specify one or more folders to run this script!')
    sys.exit()
else:
  for s in range(1,nArgv):
    # Get map file data:
    file=sys.argv[s]+'/DFM_OUTPUT_FlowFM/FlowFM_map.nc'

    ds = xr.open_dataset(file)
    nLayers = ds.mesh2d_nLayers

    velX = np.array(ds.mesh2d_ucx)
    velY = np.array(ds.mesh2d_ucy)
    velZ = np.array(ds.mesh2d_ucz)
    vel = np.sqrt(velX**2 + velY**2 + velZ**2)

    xcoords = np.array(ds.mesh2d_face_x)
    ycoords = np.array(ds.mesh2d_face_y)
    waterLevel = np.array(ds.mesh2d_s1)
    bl = np.array(ds.mesh2d_flowelem_bl)
    waterDepth = waterLevel - bl

    plt.scatter(xcoords,ycoords,s=10,c=bl)
    plt.gca().set_aspect(2)
    plt.show()

